Documentation
¶
Overview ¶
Package lockcheck detects processes that hold file locks on a directory.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FormatProcessList ¶
func FormatProcessList(procs []LockingProcess) string
FormatProcessList returns a formatted string of locking processes.
Types ¶
type LockingProcess ¶
LockingProcess represents a process that is locking a path.
func FindLockingProcesses ¶
func FindLockingProcesses(dirPath string) ([]LockingProcess, error)
FindLockingProcesses uses lsof to detect processes with open files in dirPath.
func (LockingProcess) String ¶
func (p LockingProcess) String() string
String returns a human-readable representation.
Click to show internal directories.
Click to hide internal directories.