package
Version:
v0.0.0-...-ec59030
Opens a new window with list of versions in this module.
Published: Apr 21, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package scanner walks directories and detects Git repositories.
type RepoInfo struct {
AbsolutePath string
RelativePath string
}
RepoInfo holds raw data extracted from a discovered Git repo.
ScanDir walks root recursively and returns all Git repo paths found.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.